@@ -1,6 +1,5 @@
-__version__ = "1.2.0"
-
 from dnsdist_console.console import Console
 from dnsdist_console.key import Key
 from dnsdist_console.statistics import Statistics
-from dnsdist_console.dashboard import Dashboard
\ No newline at end of file
+from dnsdist_console.dashboard import Dashboard
+from dnsdist_console.hashpwd import HashPassword
\ No newline at end of file
